@@ -11,8 +11,7 @@ from hypothesis import given
 import marisa_trie
 from .utils import text
 
-records = st.tuples(st.integers(min_value=0, max_value=2**16 - 1),
-                    st.booleans())
+records = st.tuples(st.integers(min_value=0, max_value=2 ** 16 - 1), st.booleans())
 
 
 @given(st.sets(st.tuples(text, records)))
